==> hidet-0.2.0-py3-none-any.whl: hidet/ir/primitives/cuda/math/int64.py <==
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from typing import Optional

import hidet.ir.primitives.cuda.math.float16
from hidet.ir.expr import Expr, ExprInt64, Call
from hidet.ir.type import FuncType, DataType
from hidet.ir.primitives.func import register_primitive_function, primitive_func_pool
from hidet.ir.primitives.math import MathFunctionSet, register_math_function_set


class CUDAInt64MathFunctionSet(MathFunctionSet):
    # pylint: disable=abstract-method
    def register(self):
        entries = {'min': ['min', 2], 'max': ['max', 2]}

        for name, (codegen_name, num_args) in entries.items():
            register_primitive_function(
                name='cuda_i64_{}'.format(name),
                codegen_name=codegen_name,
                func_or_type=FuncType(param_types=['int64'] * num_args, ret_type='int64'),
            )

    def call(self, name: str, *args) -> Expr:
        entry = primitive_func_pool.lookup_by_name(name)
        return Call(entry.var, args)

    def cast(self, a: ExprInt64, cast_dtype: DataType) -> Optional[Expr]:
        if cast_dtype.name == 'float16':
            return hidet.ir.primitives.cuda.math.float16.cuda_i64_to_f16(a)
        return None

    def min(self, a: Expr, b: Expr) -> Expr:
        return self.call('cuda_i64_min', a, b)

    def max(self, a: Expr, b: Expr) -> Expr:
        return self.call('cuda_i64_max', a, b)

    def sin(self, a: Expr) -> Expr:
        raise ValueError('sin is not supported for int64')

    def cos(self, a: Expr) -> Expr:
        raise ValueError('cos is not supported for int64')

    def tanh(self, a: Expr) -> Expr:
        raise ValueError('tanh is not supported for int64')

    def exp(self, a: Expr) -> Expr:
        raise ValueError('exp is not supported for int64')

    def erf(self, a: Expr) -> Expr:
        raise ValueError('erf is not supported for int64')

    def sqrt(self, a: Expr) -> Expr:
        raise ValueError('sqrt is not supported for int64')

    def rsqrt(self, a: Expr) -> Expr:
        raise ValueError('rsqrt is not supported for int64')

    def log(self, a: Expr) -> Expr:
        raise ValueError('log is not supported for int64')

    def round(self, a: Expr) -> Expr:
        raise ValueError('round is not supported for int64')

    def ceil(self, a: Expr) -> Expr:
        raise ValueError('ceil is not supported for int64')

    def floor(self, a: Expr) -> Expr:
        raise ValueError('floor is not supported for int64')

    def pow(self, a: Expr, b: Expr) -> Expr:
        raise ValueError('pow is not supported for int64')

    def fma(self, a: Expr, b: Expr, c: Expr) -> Expr:
        raise ValueError('fma is not supported for int64')


cuda_i64_math_function_set = CUDAInt64MathFunctionSet()
cuda_i64_math_function_set.register()
register_math_function_set('cuda', 'int64', cuda_i64_math_function_set)

==> hidet-0.5.0-py3-none-any.whl: hidet/ir/primitives/cuda/math/int64.py <==
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from typing import Optional

import hidet.ir.primitives.cuda.math.float16
from hidet.ir.expr import Expr, ExprInt64
from hidet.ir.type import FuncType, DataType
from hidet.ir.primitives.func import register_primitive_function, primitive_func_pool
from hidet.ir.primitives.math import MathFunctionSet, register_math_function_set


class CUDAInt64MathFunctionSet(MathFunctionSet):
    # pylint: disable=abstract-method
    def register(self):
        entries = {'min': ['min', 2], 'max': ['max', 2]}

        for name, (codegen_name, num_args) in entries.items():
            register_primitive_function(
                name='cuda_i64_{}'.format(name),
                codegen_name=codegen_name,
                func_or_type=FuncType(param_types=['int64'] * num_args, ret_type='int64'),
            )

    def call(self, name: str, *args) -> Expr:
        entry = primitive_func_pool.lookup_by_name(name)
        return entry.var(*args)

    def cast(self, a: ExprInt64, cast_dtype: DataType) -> Optional[Expr]:
        if cast_dtype.name == 'float16':
            return hidet.ir.primitives.cuda.math.float16.cuda_i64_to_f16(a)
        return None

    def min(self, a: Expr, b: Expr) -> Expr:
        return self.call('cuda_i64_min', a, b)

    def max(self, a: Expr, b: Expr) -> Expr:
        return self.call('cuda_i64_max', a, b)

    def sin(self, a: Expr) -> Expr:
        raise ValueError('sin is not supported for int64')

    def cos(self, a: Expr) -> Expr:
        raise ValueError('cos is not supported for int64')

    def tanh(self, a: Expr) -> Expr:
        raise ValueError('tanh is not supported for int64')

    def exp(self, a: Expr) -> Expr:
        raise ValueError('exp is not supported for int64')

    def erf(self, a: Expr) -> Expr:
        raise ValueError('erf is not supported for int64')

    def sqrt(self, a: Expr) -> Expr:
        raise ValueError('sqrt is not supported for int64')

    def rsqrt(self, a: Expr) -> Expr:
        raise ValueError('rsqrt is not supported for int64')

    def log(self, a: Expr) -> Expr:
        raise ValueError('log is not supported for int64')

    def round(self, a: Expr) -> Expr:
        raise ValueError('round is not supported for int64')

    def ceil(self, a: Expr) -> Expr:
        raise ValueError('ceil is not supported for int64')

    def floor(self, a: Expr) -> Expr:
        raise ValueError('floor is not supported for int64')

    def pow(self, a: Expr, b: Expr) -> Expr:
        raise ValueError('pow is not supported for int64')

    def fma(self, a: Expr, b: Expr, c: Expr) -> Expr:
        raise ValueError('fma is not supported for int64')


cuda_i64_math_function_set = CUDAInt64MathFunctionSet()
cuda_i64_math_function_set.register()
register_math_function_set('cuda', 'int64', cuda_i64_math_function_set)
